# Table of Contents

- [using-graphql-queries-with-custom-reports](<./using-graphql-queries-with-custom-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Using GraphQL Queries with Custom Reports](<./Using-GraphQL-Queries-with-Custom-Reports.md>)
  - [Overview](<./Using-GraphQL-Queries-with-Custom-Reports/Overview.md>)
  - [Prerequisites](<./Using-GraphQL-Queries-with-Custom-Reports/Prerequisites.md>)
  - [Step 1: Navigate to the Project Directory](<./Using-GraphQL-Queries-with-Custom-Reports/Step-1-Navigate-to-the-Project-Directory.md>)
  - [Step 2: Create a Custom Report Module](<./Using-GraphQL-Queries-with-Custom-Reports/Step-2-Create-a-Custom-Report-Module.md>)
  - [Step 3: Import GraphQLFactSheetCompletionReport into the Main Module](<./Using-GraphQL-Queries-with-Custom-Reports/Step-3-Import-GraphQLFactSheetCompletionReport-into-the-Main-Module.md>)
  - [Step 4: Start the Development Server](<./Using-GraphQL-Queries-with-Custom-Reports/Step-4-Start-the-Development-Server.md>)
  - [Summary](<./Using-GraphQL-Queries-with-Custom-Reports/Summary.md>)
